from globy_webcrawlers.crawler import WebSiteDataCrawler
from globy_webcrawlers.common import Logger
import asyncio
import argparse

def main() -> WebSiteDataCrawler:
    """
    Runs the crawler with user input and returns the crawler object for debugging or development purposes
    """
    # Handle user input
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "-f",
        "--urls_file",
        help="Newline separated file of URLs to scrape",
        required=True,
        default="input-urls.txt",
    )
    parser.add_argument(
        "-l", "--loglevel", help="Set log level (1-3)", required=False, type=int
    )
    parser.add_argument(
        "-o", "--output_file", help="Output CSV file path", required=False
    )
    parser.add_argument(
        "-d", "--debug", help="Debug/inspect responses (Will set PYTHONINSPECT to True)", required=False, action="store_true"
    )
    parser.add_argument(
        "-s", "--store_html_to_file", help="Store HTML all content to file per domain in the \"html_output\" folder", required=False, action="store_true"
    )
    parser.add_argument(
        "-b", "--backend", help="""
        Select backend to use for scraping (\"globy\" (default) or \"scrapy\".
        (!) The scrapy backend will only dump data for now. No analysis is supported yet.""", required=False, type=str, default="globy"
    )
    args = parser.parse_args()
    logger = Logger()
    logger.set_log_level(args.loglevel)

    # Prepare crawler and run it
    c = None
    try:
        c = WebSiteDataCrawler(debug=args.debug, store_html_to_file=args.store_html_to_file, backend=args.backend)
        if args.output_file:
            c.output_file = "outputs/" + args.output_file
        else:
            c.output_file = "outputs/" + args.urls_file + "-output.csv"
        c.load_urls_from_file(args.urls_file)
        c.run()
        c.store_dataframes_to_csv()
    except Exception as e:
        logger.logger.error(f"Errors: {e}")
    return c
