from scrapy import Spider, Request
from scrapy.crawler import CrawlerProcess
from scrapy.utils.project import get_project_settings
from pathlib import Path
from globy_webcrawlers.common import domain_from_url


class GlobySpider(Spider):
    name = 'globy'

    def __init__(self, *args, **kwargs):
        super(GlobySpider, self).__init__(*args, **kwargs)

    def start_requests(self):
        for url in self.settings.get('URLS'):
            self.headers = self.settings.get('HEADERS')
            yield Request(url, callback=self.parse, headers=self.headers)

    def parse(self, response):
        self.output_path = self.settings.get('OUTPUT_PATH')
        domain = domain_from_url(response.url)
        Path(self.output_path+'/'+domain).mkdir(parents=True, exist_ok=True)
        full_path = self.output_path+'/'+domain + '/' + domain
        with open(f'{full_path}.html', 'wb') as file:
            file.write(response.body)

        # Extract and download linked resources (e.g., CSS files)
        for css_link in response.css('link[rel="stylesheet"]::attr(href)').extract():
            yield Request(url=response.urljoin(css_link), callback=self.save_css, headers=self.headers,
                           cb_kwargs={'full_path': full_path})

    def save_css(self, response, full_path):
        with open(f'{full_path}.css', 'wb') as file:
            file.write(response.body)


def run_globy_spider(urls, output_path, headers):
    settings = get_project_settings()
    settings.set('OUTPUT_PATH', output_path)
    settings.set('HEADERS', headers)
    settings.set('URLS', urls)
    process = CrawlerProcess(settings)
    process.crawl(GlobySpider)
    process.start()